<p align="center">
<img src="app/src/res/extra/mesonui_ic.png">
</p>

* Meson-ui® is a GUI app for Meson a next-generation build system.
----------------------------------------

#### Status

[![PyPI](https://img.shields.io/pypi/v/meson-ui.svg)](https://pypi.python.org/pypi/meson-ui)
[![GitHub](https://img.shields.io/github/license/michaelbadcrumble/meson-ui.svg?color=blue)](https://github.com/michaelbadcrumble/meson-ui)
[![Travis](https://travis-ci.org/michaelbadcrumble/meson-ui.svg?branch=master)](https://travis-ci.org/michaelbadcrumble/meson-ui)
[![CircleCI](https://circleci.com/gh/michaelbadcrumble/meson-ui.svg?style=shield)](https://circleci.com/gh/michaelbadcrumble/meson-ui)
[![Codecov](https://codecov.io/gh/michaelbadcrumble/meson-ui/coverage.svg?branch=master)](https://codecov.io/gh/michaelbadcrumble/meson-ui/branch/master)
[![Code Quality: Python](https://img.shields.io/lgtm/grade/python/g/michaelbadcrumble/meson-ui.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/michaelbadcrumble/meson-ui/context:python)
[![Total Alerts](https://img.shields.io/lgtm/alerts/g/michaelbadcrumble/meson-ui.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/michaelbadcrumble/meson-ui/alerts)

## About it

Meson-ui is a Graphical application designed to provide an interactive
way to use the Meson build system. We believe it is a nice way to get
CMake users comfortable with Meson.

The main design point of Meson-ui, is that developers should have a nice
build GUI that can be summed with one simple command and count on that
GUI to provide all or most of Meson build systems features.


### Preview of the app.
<p align="center">
<img src="app/src/res/extra/preview-1.png">
</p>

<p align="center">
<img src="app/src/res/extra/preview-2.png">
</p>

## Features

*   Multiplatform support for Linux, macOS, Windows, and others
*   straight forward and easy to uses graphical user interface.
*   Written documentation for Meson-ui.
*   Meson support back to version 0.50.0.
*   Optimized for extremely fast usage without sacrificing correctness.
*   Distributed under the Apache 2.0 license.
*   Works 99.95% out of the box.
*   fun!


## Development

All development on Meson-ui is done on the [GitHub project](https://github.com/michaelbadcrumble/meson-ui). 
Instructions for contributing can be found on the [contribution page](Contributing.md).

You do not need to sign a CLA to contribute to Meson-ui.


### Downloading Required Dependencies

Meson-ui requires the following dependencies:

-----------------------------------------------------------------------------------
| Tool being used.                                     |  Version needed          |
|------------------------------------------------------|--------------------------|
| [Meson build system](https://mesonbuild.com)         | version 0.50.0 or newer. |
| [Python Language   ](https://python.org).            | version 3.6.0 or newer.  |
| [PyQt5             ](https://pypi.org/project/PyQt5/)| version 5.13.1 or newer. |


### Downloading Meson-ui.
--------

We recommended you use the Python 3 version of ‘pip’ to
install Meson-ui on to your system.

```console
pip3 install meson-ui --user
```
<br>

You can also download Meson-ui directly from GitHub with this command:

```console
git clone https://github.com/michaelbadcrumble/meson-ui.git
```
<br>

### Run Meson-ui.

To start the app, run this command:

```console
meson-ui
```

### Contact the developer.
==========================

#### Developer and maintainer

- gmail : [badcrumbles gmail](mailto:michaelbrockus@gmail.com)

#### Happy planing.  Happy coding...
